hstrat.helpers
==============

.. automodule:: hstrat.helpers

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   hstrat.helpers.AnyTreeAscendingIter
   hstrat.helpers.attach_attrs

